@@ -43,7 +43,7 @@ class Change:
     BLACKLISTED_TITLES = ("Added tag",)
 
     RE_PARSE_CONVENTIONAL_TITLE = re.compile(
-        r"^(?P<type>\w+)(\((?P<scope>.+?)\))? *: *(?P<title>.*)$"
+        r"^(?P<type>\w+)\!?(\((?P<scope>.+?)\))?\!? *: *(?P<title>.*)$"
     )
 
     RE_PARSE_TITLE = re.compile(r"^(\[(?P<scope>.+?)\])? *:? *(?P<title>.*)$")
@@ -101,6 +101,13 @@ class Change:
             if match_breaking_change:
                 breaking_change += match_breaking_change["breaking_change"]
 
+        # no breaking change detected in the body
+        # let's parse the title
+        if not breaking_change:
+            match_breaking_change = cls.RE_PARSE_BREAKING_CHANGE.match(title)
+            if match_breaking_change:
+                breaking_change = match_breaking_change["breaking_change"]
+
         return Change(
             change_type=change_type,
             title=match_title["title"],
